<?php

namespace App\Http\Controllers\Back\Catalog;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use App\Client;
use App\ClientAttachment;
use App\ClientNote;
use App\Http\Controllers\Controller;
use App\Http\Requests\Back\Catalog\Client\CreateClientRequest;
use App\Http\Requests\Back\Catalog\Client\EditClientRequest;
use App\Library\URI;
use App\MoneyType;
use App\Project;

class ClientsController extends Controller {
    public function index() {
        $data = Client::get();
        return view('back.catalog.clients.index', array('data'=>$data, 'permitions' => URI::checkPermitions()));
    }

    public function create() {
        $money_list = MoneyType::get()->pluck("name", "id");
        return view('back.catalog.clients.create', array('money_list' => $money_list));
    }

    public function store(CreateClientRequest $request) {
        $response = array('status' => false);

        DB::beginTransaction();

        $client = new Client();
        $client->client_name = $request->client_name;
        $client->social_reason = $request->social_reason;
        $client->rfc = $request->rfc;
        $client->address =  $request->address;
        $client->money_id =  $request->money_id;
        $client->iva =  $request->iva;
        $client->abreviation =  $request->abreviation;
        $client->designation =  $request->designation;
        $client->name_principal_contact =  $request->name_principal_contact;
        $client->email_principal_contact =  $request->email_principal_contact;
        $client->phone_principal_contact =  $request->phone_principal_contact;
        $client->name_secundary_contact =  $request->name_secundary_contact;
        $client->email_secundary_contact =  $request->email_secundary_contact;
        $client->phone_secundary_contact =  $request->phone_secundary_contact;

        if($client->save()) {
            //Guardamos las notas
            if($request->nota != null) {
                foreach ($request->nota as $item) {
                    if ($item != null) {
                        $nota = new ClientNote();
                        $nota->client_id = $client->id;
                        $nota->note = $item;
                        $nota->save();
                    }
                }
            }

            //Guardamos los adjuntos
            if($request->attach != null) {
                foreach ($request->attach as $item) {
                    if ($item != null) {
                        //Generamos un directorio en clients_attachments para cada cliente
                        if (is_dir("clients_attachments/" . $client->id) == false) {
                            mkdir("clients_attachments/" . $client->id);
                        }

                        $file_name = md5(date("d-m-Y-H:i:s")) . "-".rand(1000,10000)."." . $item->getClientOriginalExtension();
                        if ($item->move("clients_attachments/" . $client->id, $file_name)) {
                            $attach = new ClientAttachment();
                            $attach->client_id = $client->id;
                            $attach->url_attachment = "clients_attachments/" . $client->id . "/" . $file_name;
                            $attach->name = $item->getClientOriginalName();
                            $attach->save();
                        }
                    }
                }
            }

            DB::commit();

            $response['status'] = true;
            $response["message"] = "Los datos se han almacenado correctamente.";
            $response['url'] = route('clients_index');
        } else {
            DB::rollBack();
            $response['status'] = false;
            $response["message"] = "No hemos podido almacenar los datos, intentalo nuevamente.";
        }
        return response()->json($response);
    }

    public function view_notes($id){
        $id = base64_decode($id);
        $notes = ClientNote::where("client_id", $id)->orderBy("created_at", "DESC")->get();
        $view = view('back.catalog.clients.view_notes', array('notes' => $notes))->render();
        return response()->json($view);
    }

    public function view_attach($id) {
        $id = base64_decode($id);
        $attach = ClientAttachment::where("client_id", $id)->get();
        $view = view('back.catalog.clients.view_attach', array('attach' => $attach))->render();
        return response()->json($view);
    }

    public function edit($id) {
        $money_list = MoneyType::get()->pluck("name", "id");
        $data = Client::find(base64_decode($id));
        return view('back.catalog.clients.edit', array('money_list' => $money_list, "data" => $data));
    }

    public function update(EditClientRequest $request, $id) {
        $response = array('status' => false);

        DB::beginTransaction();

        $client = Client::find($id);
        $client->client_name = $request->client_name;
        $client->social_reason = $request->social_reason;
        $client->rfc = $request->rfc;
        $client->address =  $request->address;
        $client->money_id =  $request->money_id;
        $client->iva =  $request->iva;
        $client->abreviation =  $request->abreviation;
        $client->designation =  $request->designation;
        $client->name_principal_contact =  $request->name_principal_contact;
        $client->email_principal_contact =  $request->email_principal_contact;
        $client->phone_principal_contact =  $request->phone_principal_contact;
        $client->name_secundary_contact =  $request->name_secundary_contact;
        $client->email_secundary_contact =  $request->email_secundary_contact;
        $client->phone_secundary_contact =  $request->phone_secundary_contact;

        if($client->save()) {
            //Editamos las notas
            if($request->nota_edit != null) {
                foreach ($request->nota_edit as $key => $item) {
                    if ($item != null) {
                        $nota = ClientNote::find($key);
                        $nota->client_id = $client->id;
                        $nota->note = $item;
                        $nota->save();
                    }
                }
            }

            //Guardamos las notas nuevas
            if($request->nota != null) {
                foreach ($request->nota as $item) {
                    if ($item != null) {
                        $nota = new ClientNote();
                        $nota->client_id = $client->id;
                        $nota->note = $item;
                        $nota->save();
                    }
                }
            }

            //Guardamos los adjuntos
            if($request->attach != null) {
                foreach ($request->attach as $item) {
                    if ($item != null) {
                        //Generamos un directorio en clients_attachments para cada cliente
                        if (is_dir("clients_attachments/" . $client->id) == false) {
                            mkdir("clients_attachments/" . $client->id);
                        }

                        $file_name = md5(date("d-m-Y-H:i:s")) . "-".rand(1000,10000)."." . $item->getClientOriginalExtension();
                        if ($item->move("clients_attachments/" . $client->id, $file_name)) {
                            $attach = new ClientAttachment();
                            $attach->client_id = $client->id;
                            $attach->url_attachment = "clients_attachments/" . $client->id . "/" . $file_name;
                            $attach->name = $item->getClientOriginalName();
                            $attach->save();
                        }
                    }
                }
            }

            DB::commit();

            $response['status'] = true;
            $response["message"] = "Los datos se han actualizado correctamente.";
            $response['url'] = route('clients_index');
        } else {
            DB::rollBack();
            $response['status'] = false;
            $response["message"] = "No hemos podido actualizar los datos, intentalo nuevamente.";
        }
        return response()->json($response);
    }

    public function destroy($id) {
        $response = array(
            'status' => true,
            'message' => 'El usuario ha sido eliminado correctamente.',
            'url' => route('user_index'),
        );

        //Si un projecto depende de este cliente, no lo eliminamos
        $project = Project::where("client_id", base64_decode($id))->count();
        if( $project <= 0 ){
            $client = Client::find(base64_decode($id));
            if($client != null) {
                if($client->delete()) {
                    //Eliminamos todas las notas
                    ClientNote::where("client_id", base64_decode($id))->delete();
                    //Eliminamos todos los archivos adjuntos
                    $client_attach = ClientAttachment::where("client_id", base64_decode($id))->get();
                    foreach ($client_attach as $item){
                        if( file_exists($item->url_attachment) ){
                            unlink($item->url_attachment);
                        }
                        ClientAttachment::where("id", $item->id)->delete();
                    }
                    if( is_dir("clients_attachments/".$client->id) ){
                        rmdir("clients_attachments/".$client->id);
                    }
                    $response = [
                        'message' => 'Se ha eliminado el registro correctamente.',
                        'status' => true,
                        'url' => route('clients_index')
                    ];
                }
            } else {
                $response = [
                    'message' => 'No hemos podido eliminar el registro, intentalo nuevamente.',
                    'status' => false
                ];
            }
        } else {
            $response = [
                'message' => 'No hemos podido eliminar el registro, un proyecto depende del cliente.',
                'status' => false
            ];
        }
        return response()->json($response);
    }

    public function delete_note($id){
        $response = array(
            'status' => true,
            'message' => 'El usuario ha sido eliminado correctamente.',
            'url' => route('user_index'),
        );
        if( ClientNote::where("id", $id)->delete() ){
            $response = array(
                'status' => true,
                'message' => 'La nota se ha eliminado correctamente.',
                'url' => route('clients_index'),
            );
        }else{
            $response = array(
                'status' => true,
                'message' => 'No hemos podido eliminar la nota, intentalo nuevamente.',
            );
        }
        return response()->json($response);
    }

    public function delete_attachment($id){
        $response = array(
            'status' => true,
            'message' => 'El usuario ha sido eliminado correctamente.',
            'url' => route('user_index'),
        );

        $file_attach = ClientAttachment::find($id);
        if( ClientAttachment::where("id", $id)->delete() ){
            if( file_exists($file_attach->url_attachment) ){
                unlink($file_attach->url_attachment);
            }
            $response = array(
                'status' => true,
                'message' => 'El archivo adjunto se ha eliminado correctamente.',
                'url' => route('clients_index'),
            );
        } else {
            $response = array(
                'status' => false,
                'message' => 'No hemos podido eliminar el archivo adjunto, intentalo nuevamente.',
            );
        }
        return response()->json($response);
    }
}