<?php



namespace App\Http\Controllers\Back\Dashboard\Catalog;



use Illuminate\Http\Request;

use Illuminate\Support\Facades\DB;

use App\Http\Controllers\Controller;

use App\Http\Requests\Back\Dashboard\Catalog\ProductCategoryRequest;

use App\Library\Pastora;

use App\Library\URI;

use App\Product;

use App\ProductCategory;

use App\ProductQuestion;



class ProductCategoryController extends Controller

{



    /**

     * Display a listing of the resource.

     *

     * @return \Illuminate\Http\Response

     */

    public function index()

    {

        $brands = ProductCategory::orderBy('name', 'ASC')->get();



        return view('back.catalog.category.index', ["data" => $brands, "permitions" => URI::checkPermitions()]);

    }



    /**

     * Show the form for creating a new resource.

     *

     * @return \Illuminate\Http\Response

     */

    public function create()

    {

        $categories = ProductCategory::orderBy('name', 'asc')->get();



        return view('back.catalog.category.create', ["categories" => $categories]);

    }



    /**

     * Store a newly created resource in storage.

     *

     * @param  \Illuminate\Http\Request  $request

     * @return \Illuminate\Http\Response

     */

    public function store(ProductCategoryRequest $request)

    {

        $response = array('status' => false);



        DB::beginTransaction();



        $category = new ProductCategory();

        $category->name = $request->categoria;





        if($category->save()) {



            //Insertamos las preguntas

            foreach ($request->pregunta as $key => $pregunta){

                if($request->pregunta[$key] != "" && $request->respuesta[$key] != "") {

                    $product_question = new ProductQuestion();

                    $product_question->product_category_id = $category->id;

                    $product_question->question = $request->pregunta[$key];

                    $product_question->answer = $request->respuesta[$key];

                    $product_question->save();

                }

            }



            DB::commit();



            $response['status'] = true;

            $response["message"] = "Los datos se han almacenado correctamente.";

            $response['url'] = route('product_category_index');



        }else{

            DB::rollBack();

            $response['status'] = false;

            $response["message"] = "No hemos podido almacenar los datos, intentalo nuevamente.";

        }



        return response()->json($response);

    }



    /**

     * Show the form for editing the specified resource.

     *

     * @param  int  $id

     * @return \Illuminate\Http\Response

     */

    public function edit($id)

    {



        $data = ProductCategory::findOrFail(base64_decode($id));



        //$categories = ProductCategory::where('id', '<>', base64_decode($id))->where('category_parent_id', 0)->orderBy('name', 'asc')->get();



        return view('back.catalog.category.edit', compact('data'));

    }



    /**

     * Update the specified resource in storage.

     *

     * @param  \Illuminate\Http\Request  $request

     * @param  int  $id

     * @return \Illuminate\Http\Response

     */

    public function update(ProductCategoryRequest $request, $id)

    {

        $response = array('status' => false);



        DB::beginTransaction();



        $category = ProductCategory::find($id);

        $category->name = $request->categoria;



        if($category->save()) {



            //Eliminamos todas las preguntas actuales para despues insertar las preguntas

            ProductQuestion::where("product_category_id", $id)->delete();



            foreach ($request->pregunta as $key => $pregunta){

                if($request->pregunta[$key] != "" && $request->respuesta[$key] != "") {

                    $product_question = new ProductQuestion();

                    $product_question->product_category_id = $id;

                    $product_question->question = $request->pregunta[$key];

                    $product_question->answer = $request->respuesta[$key];

                    $product_question->save();

                }

            }





            //Actualizamos el id_referencia_category a todos los productos que tengan dicha categoria

            $category_name = Pastora::cleanStr($category->name);

            Product::where("product_category_id", $id)->update(["id_referencia_category" => $category_name]);





            DB::commit();



            $response['status'] = true;

            $response["message"] = "Los datos se han editado correctamente.";

            $response['url'] = route('product_category_index');



        }else{

            DB::rollBack();

            $response['status'] = false;

            $response["message"] = "No hemos podido editar los datos, intentalo nuevamente.";

        }



        return response()->json($response);

    }



    /**

     * Remove the specified resource from storage.

     *

     * @param  int  $id

     * @return \Illuminate\Http\Response

     */

    public function destroy($id)

    {

        $category = ProductCategory::findOrFail(base64_decode($id));



        $response = "";



        if ($category->products->count() == 0) {

            if ($category->delete()) {



                ProductQuestion::where("product_category_id", base64_decode($id))->delete();



                $response = [

                    'message' => 'Se ha eliminado el registro correctamente.',

                    'status' => true,

                    'url' => route('product_category_index')

                ];

            } else {

                $response = [

                    'message' => 'No hemos podido eliminar el registro, intentalo nuevamente.',

                    'status' => false

                ];

            }

        } else if ($category->products->count() > 0) {

            $response = [

                'message' => 'No se puede eliminar la categoría, tiene productos asociados.',

                'status' => false

            ];

        }



        return response()->json($response);

    }

}







