<?php

namespace App\Http\Controllers\Back\Dashboard\Home;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Library\URI;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\File;

use App\Http\Requests\Back\Home\Banners\CreateRequest;
use App\Http\Requests\Back\Home\Banners\EditRequest;

use App\Models\HomeBanners;


class bannersController extends Controller {
    public function index() {
        $banners = HomeBanners::get();
        return view('back.dashboard.banners.index', ["data" => $banners, "permitions" => URI::checkPermitions()]);
    }

    public function create() {
        return view('back.dashboard.banners.create');
    }

    public function store( CreateRequest $r ) {
        $response = array('status' => false);

        DB::beginTransaction();
        $banners = new HomeBanners();
        $banners->orden = $r->orden;
        $banners->status = isset($r->status) ? true : false;

        $pathBrand = "assets/images/Home/Banners/";
        if( !is_dir($pathBrand) ){
            mkdir($pathBrand, 0777, true);
        }

        if( $r->has("img") ) {
            $fileName = $r->file('img');
            $imgFile = MD5($r->img . uniqid() . microtime()) . "." . $fileName->getClientOriginalExtension();
            $fileName->move(base_path('/public/'.$pathBrand), $imgFile);
            $banners->imagen = $pathBrand . $imgFile;
        }

        if( $r->has("imgMobile") ) {
            $fileName = $r->file('imgMobile');
            $imgFile = MD5($r->imgMobile . uniqid() . microtime()) . "." . $fileName->getClientOriginalExtension();
            $fileName->move(base_path('/public/'.$pathBrand), $imgFile);
            $banners->imagen_mobile = $pathBrand . $imgFile;
        }

        if($banners->save()) {
            DB::commit();
            $response['status'] = true;
            $response["message"] = "Los datos se han almacenado correctamente.";
            $response['url'] = route('banners.index');
        } else {
            DB::rollBack();
            $response['status'] = false;
            $response["message"] = "No hemos podido almacenar los datos, intentalo nuevamente.";
        }
        return response()->json($response);
    }

    public function edit( $id ) {
        $banners = HomeBanners::where("id", base64_decode($id))->get();
        return view('back.dashboard.banners.edit', ['banners' => $banners]);
    }

    public function update(EditRequest $r, $id) { 
        $response = array('status' => false);

        DB::beginTransaction();
        $banners = HomeBanners::where("id",base64_decode($id))->get();

        $pathBrand = "assets/images/Home/Banners/";
        if( !is_dir($pathBrand) ){
            mkdir($pathBrand, 0777, true);
        }

        // Files
        $urlSave = $banners[0]->imagen;
        if( $r->has("img") ) {
            $path = ltrim($banners[0]->imagen, '/');
            if ( File::exists($path) ) {
                unlink( $path );
            }

            $fileName = $r->file('img');
            $imgFile = MD5($r->img . uniqid() . microtime()) . "." . $fileName->getClientOriginalExtension();
            $fileName->move(base_path('/public/'.$pathBrand), $imgFile);
            $urlSave = $pathBrand . $imgFile;
        } 

        // Files
        $urlSaveMobile = $banners[0]->imagen_mobile;
        if( $r->has("imgMobile") ) {
            $path = ltrim($banners[0]->imagen_mobile, '/');
            if ( File::exists($path) ) {
                unlink( $path );
            }

            $fileName = $r->file('imgMobile');
            $imgFile = MD5($r->imgMobile . uniqid() . microtime()) . "." . $fileName->getClientOriginalExtension();
            $fileName->move(base_path('/public/'.$pathBrand), $imgFile);
            $urlSaveMobile = $pathBrand . $imgFile;
        } 

        if ( HomeBanners::where("id",base64_decode($id))
            ->update(['orden' => $r->orden, 'status' => isset($r->status) ? true : false , 'imagen' => $urlSave, 'imagen_mobile' => $urlSaveMobile]) ) {
            DB::commit();
            $response['status'] = true;
            $response["message"] = "Los datos se han editado correctamente.";
            $response['url'] = route('banners.index');
        } else {
            DB::rollBack();
            $response['status'] = false;
            $response["message"] = "No hemos podido editar los datos, intentalo nuevamente.";
        }
        return response()->json($response);
    }

    public function destroy( $id ) {
        $banners = HomeBanners::find(base64_decode($id));

        if ( $banners != null ) {
            if ( $banners->delete() ) {
                File::delete($banners->imagen);
                File::delete($banners->imagen_mobile);
            }

            $banners->delete();

            $response['status'] = true;
            $response["message"] = "Se ha eliminado el registro correctamente.";
            $response['url'] = route('banners.index');

        } else {
            $response = [
                'message' => 'No hemos podido eliminar el registro, intentalo nuevamente.',
                'status' => false
            ];
        }
        return response()->json($response);
    }
}
