<?php

namespace App\Http\Controllers\Back\Dashboard\Productos;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Library\URI;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\File;

use App\Http\Requests\Back\Productos\ProductosSecciones\CreateRequest;
use App\Http\Requests\Back\Productos\ProductosSecciones\EditRequest;

use App\Models\Secciones;
use App\Models\ProductosSecciones;


class productosSeccionesController extends Controller {
    public function index() {
        $productos = ProductosSecciones::select('productos_secciones.id', 'secciones.seccion', 'productos_secciones.titulo', 'productos_secciones.imagen')
        ->join('secciones','productos_secciones.seccionId','=','secciones.id')
        ->whereNull('secciones.dt_deleted_at')
        ->get();
        return view('back.dashboard.productos-secciones.index', ["data" => $productos, "permitions" => URI::checkPermitions()]);
    }

    public function create() {
        $secciones = Secciones::get();
        return view('back.dashboard.productos-secciones.create', [ 'secciones' => $secciones ]);
    }

    public function store( CreateRequest $r ) {
        $response = array('status' => false);

        DB::beginTransaction();
        $productosSecciones = new ProductosSecciones();
        $productosSecciones->seccionId = $r->seccion;
        $productosSecciones->titulo = $r->titulo;
        $productosSecciones->desc = $r->desc;

        $pathBrand = "assets/images/Productos/ProductosSecciones/";
        if( !is_dir($pathBrand) ){
            mkdir($pathBrand, 0777, true);
        }

        if( $r->has("img") ) {
            $fileName = $r->file('img');
            $imgFile = MD5($r->img . uniqid() . microtime()) . "." . $fileName->getClientOriginalExtension();
            $fileName->move(base_path('/public/'.$pathBrand), $imgFile);
            $productosSecciones->imagen = $pathBrand . $imgFile;
        }

        if($productosSecciones->save()) {
            DB::commit();
            $response['status'] = true;
            $response["message"] = "Los datos se han almacenado correctamente.";
            $response['url'] = route('productosSecciones.index');
        } else {
            DB::rollBack();
            $response['status'] = false;
            $response["message"] = "No hemos podido almacenar los datos, intentalo nuevamente.";
        }
        return response()->json($response);
    }

    public function edit( $id ) {
        $secciones = Secciones::get();
        $productos = ProductosSecciones::where("id", base64_decode($id))->get();
        return view('back.dashboard.productos-secciones.edit', ['secciones' => $secciones, 'productos' => $productos]);
    }

    public function update(EditRequest $r, $id) { 
        $response = array('status' => false);

        DB::beginTransaction();
        $productosSecciones = productosSecciones::where("id",base64_decode($id))->get();

        $pathBrand = "assets/images/Productos/ProductosSecciones/";
        if( !is_dir($pathBrand) ){
            mkdir($pathBrand, 0777, true);
        }

        // Files
        $urlSave = $productosSecciones[0]->imagen;
        if( $r->has("img") ) {
            $path = ltrim($productosSecciones[0]->imagen, '/');
            if ( File::exists($path) ) {
                unlink( $path );
            }

            $fileName = $r->file('img');
            $imgFile = MD5($r->img . uniqid() . microtime()) . "." . $fileName->getClientOriginalExtension();
            $fileName->move(base_path('/public/'.$pathBrand), $imgFile);
            $urlSave = $pathBrand . $imgFile;
        } 

        if ( productosSecciones::where("id",base64_decode($id))->update(['seccionId' => $r->seccion, 'titulo' => $r->titulo, 'desc' => $r->desc, 'imagen' => $urlSave]) ) {
            DB::commit();
            $response['status'] = true;
            $response["message"] = "Los datos se han editado correctamente.";
            $response['url'] = route('productosSecciones.index');
        } else {
            DB::rollBack();
            $response['status'] = false;
            $response["message"] = "No hemos podido editar los datos, intentalo nuevamente.";
        }
        return response()->json($response);
    }

    public function destroy( $id ) {
        $productosSecciones = productosSecciones::find(base64_decode($id));

        if ( $productosSecciones != null ) {
            if ( $productosSecciones->delete() ) {
                File::delete($productosSecciones->imagen);
            }

            $productosSecciones->delete();

            $response['status'] = true;
            $response["message"] = "Se ha eliminado el registro correctamente.";
            $response['url'] = route('productosSecciones.index');

        } else {
            $response = [
                'message' => 'No hemos podido eliminar el registro, intentalo nuevamente.',
                'status' => false
            ];
        }
        return response()->json($response);
    }
}
